# CleanNote

![CI](https://github.com/corentinlaval/CleanNote/actions/workflows/ci.yml/badge.svg?branch=main)
![PyPI](https://github.com/corentinlaval/CleanNote/actions/workflows/release.yml/badge.svg?branch=main)
[![codecov](https://codecov.io/gh/corentinlaval/CleanNote/branch/main/graph/badge.svg?branch=main)](https://codecov.io/gh/corentinlaval/CleanNote)
[![PyPI version](https://img.shields.io/pypi/v/cleanote.svg)](https://pypi.org/project/cleanote/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)  


**CleanNote** transforms raw notes from the medical domain into standardized, clean, and structured text that can be used for analysis and clinical research.  

---

## Quickstart  

Clone the repository:  

```
git clone https://github.com/corentinlaval/CleanNote.git
cd CleanNote
python -m cleanote --config configs/base.yaml
```

*(coming soon: install & usage instructions)*  

---

## License  
This project is licensed under the [MIT License](LICENSE).  
